<?php

namespace App\Http\Controllers;

use App\Models\Unit;
use App\Models\User;
use App\Models\UserDevice;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Hash;


class UserController extends Controller
{
    

    public function profil()
    {
        $id = Auth::user()->id;
        $profiledata = User::find($id);
        return view('admin.pages.profil', compact('profiledata'));
    }

    public function updateProfile(Request $request)
    {
        $user = Auth::user();
        $validatedData = $request->validate([
            'name' => 'required|string|max:255',
            'email' => 'required|email|max:255',
        ]);
        $user->name = $validatedData['name'];
        $user->email = $validatedData['email'];
        $user->save();
        return redirect()->route('profil')->with('success', 'Profil berhasil diperbarui');
    }
    public function updatePassword(Request $request)
    {
        $request->validate([
            'new_password' => 'required|min:8|confirmed',
        ]);
        $user = Auth::user();
        $user->password = Hash::make($request->new_password);
        $user->save();
        return redirect()->back()->with('success', 'Kata sandi berhasil diperbarui.');
    }
    
    public function edit($id)
    {
        $user = User::findOrFail($id); 
        $units = Unit::all();
        return view('admin.pages.edituser', compact('user', 'units')); // Tampilkan view edit dengan data user
    }
    public function index()
    {
        $data = User::all();
        return view('admin.pages.datapegawai', compact('data'));
    }
    public function destroy($id)
    {
        $user = User::findOrFail($id); 
        $user->delete(); 
        return redirect()->route('users.index')->with('success', 'User berhasil dihapus'); 
    }
    public function update(Request $request, $id)
    {
        $request->validate([
            'name' => 'required|string|max:255',
            'email' => 'required|email|unique:users,email,' . $id,
            'role' => 'required|in:admin,user',
            'unit_id' => 'required|integer',
        ]);
        $user = User::findOrFail($id); 
        $user->name = $request->name; 
        $user->email = $request->email; 
        $user->role = $request->role; 
        $user->unit_id = $request->unit_id;
        $user->save(); 
        return redirect()->route('users.index')->with('success', 'User berhasil diperbarui.');
    }
}
