// import "highcharts/css/highcharts.css";
import "highcharts/css/stocktools/gui.css";

import axios from "axios";
import HighCharts from "highcharts";
import stock from "highcharts/modules/stock";

stock(HighCharts);

document.addEventListener("DOMContentLoaded", () => loadData());
const btnFilters = document.querySelectorAll(".js-btn-filter");
const deviceNameEl = document.getElementById("device-name");
const container = document.getElementById("container");

const loadData = async (by = "date") => {
    btnFilters.forEach((btn) => {
        btn.classList.remove("active");
        if (btn.dataset.by == by) {
            btn.classList.add("active");
        }
    });

    try {
        const { data } = await axios.get("/sensor-data/filter", {
            headers: {
                Accept: "application/json",
                "Content-Type": "application/json",
            },
            params: {
                by,
                device_name: deviceNameEl.innerText,
            },
        });
        renderChart(data.data);
    } catch (err) {
        alert("Terjadi kesalahan: \n", err.toString());
    }
};

btnFilters.forEach((btnFilter) => {
    btnFilter.addEventListener("click", () => {
        loadData(btnFilter.dataset.by);
    });
});

function renderChart(items = []) {
    const keys = Object.keys(items);



    let series = [];
    keys.forEach((key) => {
        series.push({
            name: key,
            data: items[key].map((item) => {
                const millis = Date.parse(item.waktu);
                return [millis, item.pressure || item.distance];
            }),
            type: "spline",
        });
    });

    const chart = HighCharts.stockChart("container", {
        rangeSelector: {
            selected: 1,
        },
        series,
    });
}
